local M = {}

-- HTTP Request class
local Request = {}
Request.__index = Request

function Request.new(url, payload)
    local self = setmetatable({}, Request)
    self.url = url
    self.payload = payload
    return self
end

function Request:execute(callback)
    local headers = {
        ['Content-Type'] = 'application/json',
    }

    vim.loop.http_request({
        url = self.url,
        method = 'POST',
        headers = headers,
        body = self.payload
    }, function(err, response)
        if err then
            vim.schedule(function()
                callback(nil, "HTTP request failed: " .. err)
            end)
            return
        end

        if response.status ~= 200 then
            vim.schedule(function()
                callback(nil, "HTTP request failed with status " .. response.status)
            end)
            return
        end

        local success, decoded = pcall(vim.json.decode, response.body)
        vim.schedule(function()
            if success then
                callback(decoded)
            else
                callback(nil, "JSON decode error: " .. response.body)
            end
        end)
    end)
end

M.Request = Request
return M